# Changelog

## [Unreleased]

## [0.1.2] - 2021-08-25

## Changed

- fix maturin version in `pyproject.toml`

## [0.1.1] - 2021-08-25

### Added

- `pyproject.toml` for building from source

## 0.1.0 - 2021-08-19

### Added

- initial release

[Unreleased]: https://github.com/matusf/z-base-32/compare/0.1.2...HEAD
[0.1.2]: https://github.com/matusf/z-base-32/compare/0.1.1...0.1.2
[0.1.1]: https://github.com/matusf/z-base-32/compare/0.1.0...0.1.1
